@@ -1,11 +1,12 @@
-from dagster import InputDefinition, OutputDefinition
-import pandas as pd
-import dask.dataframe as dd
 from typing import Union
-from sklearn.base import BaseEstimator
 
+import dask.dataframe as dd
+import pandas as pd
+from dagster import InputDefinition, OutputDefinition
 from qdk.base import BaseComponent
-from qdk.dagster_types import DataFrameType, SeriesType, ModelType
+from qdk.dagster_types import DataFrameType, ModelType, SeriesType
+
+from sklearn.base import BaseEstimator
 
 
 class TrainingComponent(BaseComponent):
@@ -23,8 +24,8 @@ class TrainingComponent(BaseComponent):
         cls,
         X: Union[pd.DataFrame, dd.DataFrame],
         y: Union[pd.Series, dd.Series],
-        model: Union[BaseEstimator],
-    ) -> Union[BaseEstimator]:
+        model: BaseEstimator,
+    ) -> BaseEstimator:
         raise NotImplementedError(
             'Make sure you added a "train" function to the component'
         )
