@@ -1,10 +1,10 @@
-from pandas import DataFrame, Series
-from dask.dataframe import DataFrame as DaskDataFrame, Series as DaskSeries
 from dask.array.core import Array as DaskArray
+from dask.dataframe import DataFrame as DaskDataFrame
+from dask.dataframe import Series as DaskSeries
 from numpy import ndarray
-from sklearn.base import BaseEstimator
-from mlflow.pyfunc import PyFuncModel
+from pandas import DataFrame, Series
 from qdk.mlflow import MLFlowRun
+from sklearn.base import BaseEstimator
 
 
 def is_dataframe(value) -> bool:
